==> ddna-8.0.0.tar.gz: ddna/src/Element/ShapeTabbedTable.php <==
<?php

namespace Drupal\ddna\Element;

use Drupal\Core\Render\Element\RenderElement;

/**
 * Provides a render element to display an entity.
 *
 * Properties:
 * - #entity_type: The entity type.
 * - #entity_id: The entity ID.
 * - #view_mode: The view mode that should be used to render the entity.
 * - #langcode: For which language the entity should be rendered.
 *
 * Usage Example:
 * @code
 * $build['node'] = [
 *   '#type' => 'shape_tabbed_table',
 *   '#seeds' => [],
 * ];
 * @endcode
 *
 * @RenderElement("shape_tabbed_table")
 */
class ShapeTabbedTable extends RenderElement {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    return [
      '#pre_render' => [
        [get_class($this), 'preRenderElement'],
      ],
      '#seeds' => [],
    ];
  }

  /**
   * Entity element pre render callback.
   *
   * @param array $element
   *   An associative array containing the properties of the entity element.
   *
   * @return array
   *   The modified element.
   */
  public static function preRenderElement(array $element) {
    if(empty($element['#seeds'])) {
      return ['#markup' => 'There are no seeds available'];
    }

    $tabs = [];
    $tabs_content = [];
    foreach($element['#seeds'] as $seed) {
      $tabs[] = $seed->configuration['label'];

      $page['table'] = [
        '#type' => 'table',
        '#header' => [
          'name' => 'YAML',
        ],
        '#attributes' => [
          'class' => [
            'yml-ddna-list',
          ],
        ],
      ];

      foreach ($seed->getElements() as $name) {
        $label = '<span class="table__filter--text-source">' . $name . '</span>';
        $page['table'][] = [
          'name' => ['#markup' => $label],
        ];
      }

      $tabs_content[] = $page;
    }

    $element['tabs'] = [
      '#theme' => 'ddna_tabbed_table',
      '#tabs' => $tabs,
      '#content' => $tabs_content,
      '#attached' => [
        'library' => ['ddna/ddna_tabbed_table']
      ],
    ];

    return $element;
//    return ['#markup' => 'TabbedTable'];
  }

}

==> ddna-8.1.0.tar.gz: ddna/src/Element/ShapeTabbedTable.php <==
<?php

namespace Drupal\ddna\Element;

use Drupal\Core\Render\Element\RenderElement;

/**
 * Provides a render element to display an entity.
 *
 * Properties:
 * - #entity_type: The entity type.
 * - #entity_id: The entity ID.
 * - #view_mode: The view mode that should be used to render the entity.
 * - #langcode: For which language the entity should be rendered.
 *
 * Usage Example:
 * @code
 * $build['node'] = [
 *   '#type' => 'shape_tabbed_table',
 *   '#seeds' => [],
 * ];
 * @endcode
 *
 * @RenderElement("shape_tabbed_table")
 */
class ShapeTabbedTable extends RenderElement {

  /**
   * {@inheritdoc}
   */
  public function getInfo() {
    return [
      '#pre_render' => [
        [get_class($this), 'preRenderElement'],
      ],
      '#seeds' => [],
    ];
  }

  /**
   * Entity element pre render callback.
   *
   * @param array $element
   *   An associative array containing the properties of the entity element.
   *
   * @return array
   *   The modified element.
   */
  public static function preRenderElement(array $element) {
    if(empty($element['#seeds'])) {
      return ['#markup' => 'There are no seeds available'];
    }

    $tabs = [];
    $tabs_content = [];
    foreach($element['#seeds'] as $seed) {
      $tabs[] = $seed->configuration['label'];

      list($header, $rows) = $seed->getElements();
      $page['table'] = [
        '#type' => 'table',
        '#header' => $header,
        '#attributes' => [
          'class' => [
            'yml-ddna-list',
          ],
        ],
      ];

      foreach ($rows as $row) {
        $cols = [];
        foreach($row as $col) {
          $cols[] = ['#markup' => '<span class="table__filter--text-source">' . $col . '</span><span>&#8592;<span>&#9740;</span><span>&#9741;</span></span>'];
        }
        $page['table'][] = $cols;
      }

      $tabs_content[] = $page;
    }

    $element['tabs'] = [
      '#theme' => 'ddna_tabbed_table',
      '#tabs' => $tabs,
      '#content' => $tabs_content,
      '#attached' => [
        'library' => ['ddna/ddna_tabbed_table']
      ],
    ];

    return $element;
//    return ['#markup' => 'TabbedTable'];
  }

}
